@@ -6,6 +6,7 @@ import (
 	"os"
 
 	"github.com/google/go-github/v71/github"
+	"github.com/sirupsen/logrus"
 	"golang.org/x/oauth2"
 )
 
@@ -20,16 +21,23 @@ type (
 	Commit            = github.Commit
 )
 
-func New(ctx context.Context) *Client {
-	return github.NewClient(getHTTPClientForGitHub(ctx, getGitHubToken()))
+func New(ctx context.Context, logE *logrus.Entry) *Client {
+	return github.NewClient(getHTTPClientForGitHub(ctx, logE, getGitHubToken()))
 }
 
 func getGitHubToken() string {
 	return os.Getenv("GITHUB_TOKEN")
 }
 
-func getHTTPClientForGitHub(ctx context.Context, token string) *http.Client {
+func checkKeyringEnabled() bool {
+	return os.Getenv("PINACT_KEYRING_ENABLED") == "true"
+}
+
+func getHTTPClientForGitHub(ctx context.Context, logE *logrus.Entry, token string) *http.Client {
 	if token == "" {
+		if checkKeyringEnabled() {
+			return oauth2.NewClient(ctx, NewKeyringTokenSource(logE))
+		}
 		return http.DefaultClient
 	}
 	return oauth2.NewClient(ctx, oauth2.StaticTokenSource(
